Translate Toolkit 3.6.1 — Translate Toolkit 3.6.2 documentation

# Translate Toolkit 3.6.1

Released on 10 May 2022

This release contains improvements and bug fixes.

## Changes

### Formats and Converters

- JSON

  - Avoid parsing root node

- YAML

  - Improve strings removal

- Properties

  - Fixing backslash problems for iOS strings

- RC

  - Avoid parsing #pragma statements from inside strings

## Contributors

This release was made possible by the following people:

Michal Čihař, Nathan Fallet